import sys
import typing


def new_triangles(range, coords, colors) -> int:
    '''

    :param range: Pair of ints. 
    :param coords: Sequence of bytes (6 floats for one triangle) for (X, Y) coordinates. 
    :param colors: Sequence of ints (12 for one triangles) for RGBA. 
    :return:  Unique icon value (pass to interface icon_value argument). 
    '''

    pass


def new_triangles_from_file(filename) -> int:
    '''

    :param filename: File path. 
    :return:  Unique icon value (pass to interface icon_value argument). 
    '''

    pass


def release(icon_id):
    '''

    '''

    pass



import sys
import typing
import bmesh


def intersect_face_point(face: 'bmesh.types.BMFace', point: float) -> bool:
    '''Tests if the projection of a point is inside a face (using the face’s normal). 

    :param face: The face to test. 
    :type face: 'bmesh.types.BMFace'
    :param point: The point to test. 
    :type point: float
    :return:  True when the projection of the point is in the face. 
    '''

    pass
